summaryrefslogtreecommitdiff
path: root/test
diff options
context:
space:
mode:
authorMarkus Kauppila <markus.kauppila@gmail.com>2011-08-11 22:26:33 +0300
committerMarkus Kauppila <markus.kauppila@gmail.com>2011-08-11 22:26:33 +0300
commite7a96e5eee19e734f5143c84cb3e640073c267f0 (patch)
treeb27ac337dc394d86d4781d924278174e77c814bd /test
parentf43e982466e746ebe92c8dac43a4d74b340ca33e (diff)
Fixed the doxygen markup.
Diffstat (limited to 'test')
-rw-r--r--test/test-automation/src/libSDLtest/fuzzer/fuzzer.c10
-rw-r--r--test/test-automation/src/libSDLtest/fuzzer/fuzzer.h4
-rw-r--r--test/test-automation/src/libSDLtest/plain_logger.h4
-rw-r--r--test/test-automation/src/libSDLtest/xml_logger.h4
-rw-r--r--test/test-automation/src/runner/runner.c2
-rw-r--r--test/test-automation/tests/testrwops/testrwops.c9
6 files changed, 14 insertions, 19 deletions
diff --git a/test/test-automation/src/libSDLtest/fuzzer/fuzzer.c b/test/test-automation/src/libSDLtest/fuzzer/fuzzer.c
index 53726f4c..fdbb7e04 100644
--- a/test/test-automation/src/libSDLtest/fuzzer/fuzzer.c
+++ b/test/test-automation/src/libSDLtest/fuzzer/fuzzer.c
@@ -217,7 +217,6 @@ RandomIntegerInRange(Sint32 pMin, Sint32 pMax)
* \param validDomain Generate only for valid domain (for the data type)
*
* \param outBuffer The generated boundary values are put here
- * \param outBufferSize Size of outBuffer
*
* \returns Returns the number of elements in outBuffer or -1 in case of error
*/
@@ -382,7 +381,11 @@ RandomUint64BoundaryValue(Uint64 boundary1, Uint64 boundary2, SDL_bool validDoma
* If boundary1 == boundary2, value of boundary1 will be returned
*
* Generating boundary values for Sint8:
- * <Add examples>
+ * SignedBoundaryValues(sizeof(Sint8), -10, 20, True) -> [-11,-10,19,20]
+ * SignedBoundaryValues(sizeof(Sint8), -10, 20, False) -> [-11,21]
+ * SignedBoundaryValues(sizeof(Sint8), -30, -15, True) -> [-30, -29, -16, -15]
+ * SignedBoundaryValues(sizeof(Sint8), -128, 15, False) -> [16]
+ * SignedBoundaryValues(sizeof(Sint8), -128, 127, False) -> NULL
*
* Generator works the same for other types of signed integers.
*
@@ -390,7 +393,7 @@ RandomUint64BoundaryValue(Uint64 boundary1, Uint64 boundary2, SDL_bool validDoma
* If outbuffer != NULL, it'll be freed.
*
*
- * \paran minValue The smallest value that is acceptable for this data type.
+ * \param minValue The smallest value that is acceptable for this data type.
* For instance, for Uint8 -> -128, Uint16 -> -32,768 etc.
* \param maxValue The biggest value that is acceptable for this data type.
* For instance, for Uint8 -> 127, Uint16 -> 32767 etc.
@@ -399,7 +402,6 @@ RandomUint64BoundaryValue(Uint64 boundary1, Uint64 boundary2, SDL_bool validDoma
* \param validDomain Generate only for valid domain (for the data type)
*
* \param outBuffer The generated boundary values are put here
- * \param outBufferSize Size of outBuffer
*
* \returns Returns the number of elements in outBuffer or -1 in case of error
*/
diff --git a/test/test-automation/src/libSDLtest/plain_logger.h b/test/test-automation/src/libSDLtest/plain_logger.h
index 9e434fa5..a0e1d619 100644
--- a/test/test-automation/src/libSDLtest/plain_logger.h
+++ b/test/test-automation/src/libSDLtest/plain_logger.h
@@ -32,7 +32,7 @@
* \param runnerParameters What parameters were given to the runner
* \param runSeed Fuzzer seed of the harness
* \param eventTime When the execution started
- * \param loggerData LoggerData structure which contains data for the logger
+ * \param data LoggerData structure which contains data for the logger
*
*/
void PlainRunStarted(int parameterCount, char *runnerParameters[], char *runSeed,
@@ -134,8 +134,8 @@ void PlainAssertSummary(int numAsserts, int numAssertsFailed, int numAssertsPass
/*!
* Prints given message
*
- * \param logMessage Message to be logged
* \param eventTime Timestamp for log message
+ * \param fmt Message to be logged
*/
void PlainLog(time_t eventTime, char *fmt, ...);
diff --git a/test/test-automation/src/libSDLtest/xml_logger.h b/test/test-automation/src/libSDLtest/xml_logger.h
index 6094850e..7ca6f58c 100644
--- a/test/test-automation/src/libSDLtest/xml_logger.h
+++ b/test/test-automation/src/libSDLtest/xml_logger.h
@@ -32,7 +32,7 @@
* \param runnerParameters What parameters were given to the runner
* \param runSeed Fuzzer seed of the harness
* \param eventTime When the execution started
- * \param loggerData LoggerData structure which contains data for the logger
+ * \param data LoggerData structure which contains data for the logger
*/
void XMLRunStarted(int parameterCount, char *runnerParameters[], char *runSeed,
time_t eventTime, LoggerData *data);
@@ -132,8 +132,8 @@ void XMLAssertSummary(int numAsserts, int numAssertsFailed, int numAssertsPass,
/*!
* Prints given message in XML
*
- * \param logMessage Message to be logged
* \param eventTime Timestamp for log message
+ * \param fmt Message to be logged
*/
void XMLLog(time_t eventTime, char *fmt, ...);
diff --git a/test/test-automation/src/runner/runner.c b/test/test-automation/src/runner/runner.c
index eabd2b9c..03f44bcc 100644
--- a/test/test-automation/src/runner/runner.c
+++ b/test/test-automation/src/runner/runner.c
@@ -824,6 +824,8 @@ RunTest(TestCase *testCase, Uint64 execKey)
* be executed in-proc or out-of-proc.
*
* \param testItem The test case that will be executed
+ * \param execKey Execution key for the test case
+ *
* \return The return value of the test. Zero means success, non-zero failure.
*/
int
diff --git a/test/test-automation/tests/testrwops/testrwops.c b/test/test-automation/tests/testrwops/testrwops.c
index 47d5f17d..c17e8bfc 100644
--- a/test/test-automation/tests/testrwops/testrwops.c
+++ b/test/test-automation/tests/testrwops/testrwops.c
@@ -123,15 +123,6 @@ void rwops_testParam (void)
/**
- * @brief Does a generic rwops test.
- *
- * RWops should have "Hello World!" in it already if write is disabled.
- *
- * @param write Test writing also.
- * @return 1 if an assert is failed.
- */
-
-/**
* @brief Tests opening from memory.
*
* \sa http://wiki.libsdl.org/moin.cgi/SDL_RWFromMem
diff --git a/test/test-automation/src/libSDLtest/fuzzer/fuzzer.h b/test/test-automation/src/libSDLtest/fuzzer/fuzzer.h
index a3692d38..02143f85 100644
--- a/test/test-automation/src/libSDLtest/fuzzer/fuzzer.h
+++ b/test/test-automation/src/libSDLtest/fuzzer/fuzzer.h
@@ -322,12 +322,12 @@ char *RandomAsciiStringWithMaximumLength(int maxLength);
* \param runSeed Seed of the harness
* \param suiteName Test suite name
* \param testName Test name
* \param iteration Number of test iteration
*
* \return Generated execution key as blob of 16 bytes. It needs be deallocated.
* On error, returns NULL.
*/
-Uint64 GenerateExecKey(char *runSeed, char *suiteName, char *testName, int interationNumber);
+Uint64 GenerateExecKey(char *runSeed, char *suiteName, char *testName, int iterationNumber);
#endif
@@ -322,12 +322,12 @@ char *RandomAsciiStringWithMaximumLength(int maxLength);
* \param suiteName Test suite name
* \param testName Test name
- * \param iteration Number of test iteration
+ * \param iterationNumber of test iteration
*
* \return Generated execution key as blob of 16 bytes. It needs be deallocated.